# Development

In order to run project-related tasks defined in `tasks.py`, its immediate dependencies must first be installed:

    $ pip install . chevron==0.14

The package can now be installed in development mode via `yatte` itself:

    $ yatte setup

Other project-related tasks can then be listed and run:

    $ yatte
    $ yatte fmt  # etc.

To add a pre-commit hook to check the code when committing, write the following to `.git/hook/pre-commit` and `chmod +x` it:

    #!/bin/sh -e
    yatte check

Note: The `man` task has the following non-Python dependency, which must be installed separately:

- scdoc